aboutsummaryrefslogtreecommitdiffstats
path: root/mayor-orig/www/include/share/facebook/Helpers
diff options
context:
space:
mode:
Diffstat (limited to 'mayor-orig/www/include/share/facebook/Helpers')
-rw-r--r--mayor-orig/www/include/share/facebook/Helpers/FacebookRedirectLoginHelper.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/mayor-orig/www/include/share/facebook/Helpers/FacebookRedirectLoginHelper.php b/mayor-orig/www/include/share/facebook/Helpers/FacebookRedirectLoginHelper.php
index 4a0755a4..3240ba81 100644
--- a/mayor-orig/www/include/share/facebook/Helpers/FacebookRedirectLoginHelper.php
+++ b/mayor-orig/www/include/share/facebook/Helpers/FacebookRedirectLoginHelper.php
@@ -222,8 +222,8 @@ class FacebookRedirectLoginHelper
$this->resetCsrf();
$redirectUrl = $redirectUrl ?: $this->urlDetectionHandler->getCurrentUrl();
- // At minimum we need to remove the state param
- $redirectUrl = FacebookUrlManipulator::removeParamsFromUrl($redirectUrl, ['state']);
+ // At minimum we need to remove the 'state' and 'code' params
+ $redirectUrl = FacebookUrlManipulator::removeParamsFromUrl($redirectUrl, ['code', 'state']);
return $this->oAuth2Client->getAccessTokenFromCode($code, $redirectUrl);
}